import React, { useEffect, useState } from 'react';
import { Box } from '@material-ui/core';
import { useSelector, useDispatch } from 'react-redux';
import { Label, Sample, Button } from './styles';
import icon from '../../assets/icons/contraste.svg';
import iconAtivo from '../../assets/icons/contraste-ativo.svg';
import { Toggle } from 'react-toggle-component';

export default function (props) {
  const [bool, setBool] = useState(false);
  const contrasteValue = useSelector((state) => state.contraste);
  const dispatch = useDispatch();
  const toggleContraste = (value) => {
    dispatch({ type: 'CONTRASTE', value: !contrasteValue });
  };

  function handleKeyboardC(event) {
    const btnToggle = document.querySelector('.react-toggle input');
    if (event === 'click' || event.key === 'c') {
      btnToggle.click();
      window.removeEventListener('keydown', handleKeyboardC);
      setBool(!bool);
    } else if (event === 'clickInput') {
      toggleContraste();
    }
  }

  useEffect(() => {
    window.addEventListener('keydown', handleKeyboardC);
  }, [bool]);

  return (
    <Box>
      <Sample>
        <Label htmlFor='toggle-1'>
          <Button
            contraste={contrasteValue}
            onClick={() => handleKeyboardC('click')}
            data-tooltip={
              contrasteValue ? 'Desativar Contraste' : 'Ativar contraste'
            }
            tooltip
          >
            {contrasteValue ? (
              <img src={iconAtivo} className='svg' alt='' />
            ) : (
              <img src={icon} className='svg' alt='' />
            )}
          </Button>
          <Toggle
            leftBackgroundColor='white'
            rightBackgroundColor='black'
            borderColor='white'
            leftKnobColor={(props) => props.theme.palette.white.components}
            rightKnobColor='#fff'
            checked={contrasteValue}
            name='toggle-3'
            onToggle={() => toggleContraste()}
          />
        </Label>
      </Sample>
    </Box>
  );
}
