import React, {
  useState,
  useRef,
  forwardRef,
  useImperativeHandle,
} from "react";
import { useSelector } from "react-redux";
import styled from "styled-components";
import clsx from "clsx";
import { makeStyles } from "@material-ui/core/styles";
import ReadDrawer from "./ReadDrawer/ReadDrawer";
import {
  Box,
  Drawer,
  List,
  Divider,
  ListItem,
  ListItemIcon,
  ListItemText,
  Typography,
  ListSubheader,
} from "@material-ui/core";

import { CreditsIcon, ReferencesIcon, QuoteIcon } from "./icons";

import ArrowBackIcon from "@material-ui/icons/ArrowBack";
import Close from "@material-ui/icons/CancelRounded";
import LinkIcon from "@material-ui/icons/OpenInNewRounded";

import RoundButton from "../RoundButton";

import references from "./references";
import credits from "./credits";
import comocitar from "./citar";

import themeLight from "../../theme/Palette/Light/palette.js";
import themeDark from "../../theme/Palette/Dark/palette.js";
import themeDefault from "../../theme";

const useStyles = makeStyles({
  list: {
    width: 250,
    height: "100vh",
    "@media(min-width: 900px)": {
      minWidth: 368,
    },
    overflow: "hidden",
  },
  fullList: {
    width: "auto",
  },
  icons: {
    // color: 'white',
    fontSize: "2.5rem",
    margin: "0 10px",
    "@media(min-width: 900px)": {
      fontSize: "3rem",
      margin: "0.5rem",
    },

    "@media(min-width: 1800px)": {
      fontSize: "3.5rem",
    },
  },
  ListItem: {
    borderRadius: "10px",
    width: "95%",
    marginLeft: "2.5%",
    marginRight: "2.5%",
    transition: "0.2s ease",

    "&:hover": {
      transition: "0.2s ease",
      backgroundColor: (theme) => theme.palette.black.light,
      color: (theme) => theme.palette.white.black,
      fill: (theme) => theme.palette.white.titles,
    },

    "&:focus": {
      transition: "0.2s ease",
      backgroundColor: (theme) => theme.palette.black.light,
      color: (theme) => theme.palette.white.titles,
    },
  },
  ListItemText: {
    borderRadius: "10px",
    width: "95%",
    margin: "0 2.5%",
    transition: "0.2s ease",
    marginBottom: "0.25rem",
    p: {
      fontWeight: 900,
    },
    "&:focus": {
      transition: "0.2s ease",
      backgroundColor: (theme) => theme.palette.black.light,
      color: (theme) => theme.palette.white.titles,
    },
  },
  ListTitle: {
    background: (theme) => theme.palette.black.light,
    color: (theme) => theme.palette.white.titles,
  },
  ListTitleBox: {
    width: "95%",
    margin: "auto",
    "@media(max-width: 600px)": {
      padding: "0 !important",
    },
    padding: "0 .4rem ",
    "@media(min-width: 900px)": {
      width: "100%",
    },
  },
  ListItemActive: {
    // backgroundColor: (theme) => theme.palette.primary.lighter,
    color: (theme) => theme.palette.black.componentsHover,
    borderRadius: "10px",
    width: "95%",
    margin: "0px 2.5%",
    p: {
      fontWeight: "900",
    },
  },
  ListIcon: {
    fill: "#333",
    display: "flex",
    justifyContent: "center",
    "&:focus": {
      color: (theme) => theme.palette.white.titles,
    },
  },
  ListIconActive: {
    color: (theme) => theme.palette.white.titles,
    display: "flex",
    justifyContent: "flex-start",
  },
  RefLink: {
    opacity: 0.9,
    lineHeight: 1,
  },
  CreditOccupation: {
    textTransform: "uppercase",
    lineHeight: 1.1,
    margin: ".75rem 0",
    fontSize: "1.1rem",
    "@media(min-width: 1200px)": {
      fontSize: "1.2rem",
    },
    "@media(min-width: 1800px)": {
      fontSize: "1.4rem",
    },
  },
  ItemName: {
    fontSize: "1.1rem",
    "@media(min-width: 1200px)": {
      fontSize: "1.2rem",
    },
    "@media(min-width: 1800px)": {
      fontSize: "1.3rem",
    },
  },
  ContentList: {
    height: "90vh",
    overflow: "auto",
    "&::-webkit-scrollbar": {
      width: "8px",
      "@media(min-width: 900px)": {
        width: "8px",
      },
    },
    "&::-webkit-scrollbar-thumb": {
      backgroundColor: (theme) => theme.palette.white.components,
      borderRadius: "10px",
      border: "2px solid white",
      "-webkit-box-shadow": "inset 0 0 6px rgba(0, 0, 0, 0.5)",
    },
  },
  ArrowBack: {
    cursor: "pointer",
  },
  tooltip: {
    display: "none",
  },
  Title: {
    fontWeight: "900",
  },
  ActiveIcon: {
    color: (theme) => theme.palette.white.buttons,
  },
  HasLink: {
    height: "fit-content",
    margin: "0",
    padding: "0",
    paddingBottom: {
      lineHeight: 1,
      margin: "0",
      padding: "0",
    },
  },
  Link: {
    color: (theme) => theme.palette.black.links,
    fontWeight: (contraste) => (contraste ? "bolder" : "regular"),
    lineHeight: 1,
    margin: "0",
    padding: "0",
    fontSize: "0.9rem",
    "@media(min-width: 1200px)": {
      fontSize: "1.1rem",
    },
  },
  ItemLink: {
    marginTop: ".25rem",
  },
  IconWrapper: {
    width: "1.8rem",
    overflow: "hidden",
  },
  refNumber: {
    background: (theme) => theme.palette.black.titles,
    color: (theme) => theme.palette.white.white,
    padding: ".05rem .25rem",
    borderRadius: ".25rem",
  },
  copyright: {
    margin: ".75rem 2.5%",
    paddingTop: "3rem",
  },
});

const TopBox = styled.div`
  display: flex;
  align-items: center;
  height: 3rem;
  padding: 0 1rem;

  @media (max-height: 500px) {
    height: 40px;
  }

  @media (min-width: 600px) {
    min-height: 56px;
  }

  @media (min-width: 900px) {
    height: 3.5rem;
    padding: 0 1.75rem;
  }

  @media (min-width: 900px) and (min-height: 900px) {
    height: 4rem;
  }
`;

const ButtonBack = styled.button`
  background: transparent;
  border: none;
`;
const BoxFlex = styled.div`
  display: flex;
  justify-content: space-between;
  flex-grow: 1;
  align-items: center;
`;

const InfoDrawer = (props, ref) => {
  const contraste = useSelector((state) => state.contraste);
  const theme = contraste ? themeDark : themeLight;
  const classes = useStyles(theme);
  const [opened, setOpened] = useState(false);
  const [menu, setMenu] = useState(true);
  const [refs, setRefs] = useState(false);
  const [creds, setCreds] = useState(false);
  const [citar, setCitar] = useState(false);
  const [selected, setSelected] = useState(0);
  const listRef = useRef();
  const { acess } = props;

  const toggleDrawer = (open, select) => (event, close) => {
    console.log(close);
    if (event.key === "Enter") {
      event.preventDefault();
      setOpened(open);
      // setSelected(select)
    } else if (event.key === "Tab" || event.key === "Shift") {
      return true;
    } else {
      setOpened(open);
      setSelected(select);
    }
  };

  const open = (option) => {
    if (option === "refs") {
      setMenu(false);
      setRefs(true);
      setCreds(false);
      setCitar(false);
    } else if (option === "creds") {
      setMenu(false);
      setRefs(false);
      setCreds(true);
      setCitar(false);
    } else if (option === "citar") {
      setMenu(false);
      setRefs(false);
      setCitar(true);
      setCreds(false);
    } else if (option === "imagens") {
      setMenu(false);
      setRefs(false);
      setCitar(false);
      setCreds(false);
    } else if (option === "menu") {
      setRefs(false);
      setCreds(false);
      setCitar(false);
      setMenu(true);
    }
  };

  useImperativeHandle(ref, () => ({
    openDrawer: (key) => {
      setOpened(true);
      setSelected(key);
      open("refs");
    },
    scrollList: () => {
      if (listRef.current) {
        if (listRef.current.childNodes[selected - 1]) {
          listRef.current.childNodes[selected - 1].scrollIntoView();
        }
      }
    },
  }));

  const menuList = (anchor) => (
    <div
      className={clsx(classes.list, {
        [classes.fullList]: anchor === "top" || anchor === "bottom",
      })}
      role="presentation"
      // onKeyPress={toggleDrawer(false)}
    >
      <List className={classes.ListTitle}>
        <TopBox className={classes.ListTitleBox}>
          <ListItemIcon className={classes.ArrowBack}>
            <ButtonBack
              onClick={toggleDrawer(false)}
              onKeyPress={toggleDrawer(false)}
            >
              <Close className={classes.ActiveIcon} />
              <Typography className={classes.tooltip}>
                Botão “Ocultar Menu”
              </Typography>
            </ButtonBack>
          </ListItemIcon>
          <BoxFlex>
            <Typography variant="body1" className={classes.Title}>
              MENU
            </Typography>
            {acess && <ReadDrawer contrasteValue={contraste} />}
          </BoxFlex>
        </TopBox>
      </List>
      <List>
        <ListItem
          className={classes.ListItem}
          button
          key={1}
          onClick={() => open("creds")}
        >
          <ListItemIcon className={classes.ListIconActive}>
            <Box className={classes.IconWrapper}>
              {/* AQUI VOCÊ MUDA A COR DO ICONES DO DRAWER */}
              <CreditsIcon
                fill={
                  contraste
                    ? theme.palette.black.titles
                    : theme.palette.white.titles
                }
              />
            </Box>
          </ListItemIcon>
          <ListItemText disableTypography>
            <Typography variant="body1">Créditos</Typography>
          </ListItemText>
        </ListItem>
      </List>
      <List>
        <ListItem
          className={classes.ListItem}
          button
          key={2}
          onClick={() => open("refs")}
        >
          <ListItemIcon className={classes.ListIconActive}>
            <Box className={classes.IconWrapper}>
              {/* AQUI VOCÊ MUDA A COR DO ICONES DO DRAWER */}
              <ReferencesIcon
                fill={
                  contraste
                    ? theme.palette.black.titles
                    : theme.palette.white.titles
                }
              />
            </Box>
          </ListItemIcon>
          <ListItemText disableTypography>
            <Typography variant="body1">Referências</Typography>
          </ListItemText>
        </ListItem>
      </List>
      <List>
        <ListItem
          className={classes.ListItem}
          button
          key={2}
          onClick={() => open("citar")}
        >
          <ListItemIcon className={classes.ListIconActive}>
            <Box className={classes.IconWrapper}>
              {/* AQUI VOCÊ MUDA A COR DO ICONES DO DRAWER */}
              <QuoteIcon
                fill={
                  contraste
                    ? theme.palette.black.titles
                    : theme.palette.white.titles
                }
              />
            </Box>
          </ListItemIcon>
          <ListItemText disableTypography>
            <Typography variant="body1">Como citar este material</Typography>
          </ListItemText>
        </ListItem>
      </List>
    </div>
  );

  const refsList = (anchor) => {
    return (
      <div
        className={clsx(classes.list, {
          [classes.fullList]: anchor === "top" || anchor === "bottom",
        })}
        role="presentation"
      >
        <List className={classes.ListTitle}>
          <TopBox className={classes.ListTitleBox}>
            <ListItemIcon className={classes.ArrowBack}>
              <ButtonBack
                onClick={() => open("menu")}
                onKeyPress={() => open("menu")}
              >
                <ArrowBackIcon className={classes.ActiveIcon} />
                <Typography className={classes.tooltip}>
                  Botão “Ocultar Referências”
                </Typography>
              </ButtonBack>
            </ListItemIcon>
            <BoxFlex>
              <Typography variant="body2" className={classes.Title}>
                REFERÊNCIAS
              </Typography>
              <ReadDrawer contrasteValue={contraste} />
            </BoxFlex>
          </TopBox>
        </List>
        {/* referências */}
        <List className={classes.ContentList} ref={listRef}>
          {references.map((ref, i) => {
            return (
              <ListItem key={i} selected={selected === i + 1}>
                <ListItemText disableTypography>
                  <Typography variant="body1" className={classes.ItemName}>
                    <strong>{i + 1}</strong>
                    {". "}
                    {ref.info}
                  </Typography>
                  {ref.link ? (
                    <Typography
                      variant="body2"
                      className={[classes.ItemLink, classes.ItemName]}
                    >
                      Disponível{" "}
                      <a
                        href={ref.link}
                        target="_blank"
                        rel="noopener noreferrer"
                        className={classes.Link}
                      >
                        <strong>clicando aqui</strong>
                      </a>
                    </Typography>
                  ) : (
                    <></>
                  )}
                </ListItemText>
              </ListItem>
            );
          })}
        </List>
      </div>
    );
  };

  const citarList = (anchor) => {
    return (
      <div
        className={clsx(classes.list, {
          [classes.fullList]: anchor === "top" || anchor === "bottom",
        })}
        role="presentation"
      >
        <List className={classes.ListTitle}>
          <TopBox className={classes.ListTitleBox}>
            <ListItemIcon className={classes.ArrowBack}>
              <ButtonBack
                onClick={() => open("menu")}
                onKeyPress={() => open("menu")}
              >
                <ArrowBackIcon className={classes.ActiveIcon} />
                <Typography className={classes.tooltip}>
                  Botão “Ocultar Como Citar este Material”
                </Typography>
              </ButtonBack>
            </ListItemIcon>
            <BoxFlex>
              <Typography variant="body2" className={classes.Title}>
                COMO CITAR ESTE MATERIAL
              </Typography>
              <ReadDrawer contrasteValue={contraste} />
            </BoxFlex>
          </TopBox>
        </List>
        {/* referências */}
        <List className={classes.ContentList} ref={listRef}>
          {comocitar.map((quote, i) => {
            return (
              <ListItem key={i} selected={selected === i + 1}>
                <ListItemText disableTypography>
                  <Typography variant="body1" className={classes.ItemName}>
                    {quote.text}
                  </Typography>
                </ListItemText>
              </ListItem>
            );
          })}
        </List>
      </div>
    );
  };

  const creditsList = (anchor) => {
    return (
      <div
        className={clsx(classes.list, {
          [classes.fullList]: anchor === "top" || anchor === "bottom",
        })}
        role="presentation"
      >
        <List className={classes.ListTitle}>
          <TopBox className={classes.ListTitleBox}>
            <ListItemIcon className={classes.ArrowBack}>
              <ButtonBack
                onClick={() => open("menu")}
                onKeyPress={() => open("menu")}
              >
                <ArrowBackIcon className={classes.ActiveIcon} />
                <Typography className={classes.tooltip}>
                  Botão “Ocultar Créditos”
                </Typography>
              </ButtonBack>
            </ListItemIcon>
            <BoxFlex>
              <Typography variant="body2" className={classes.Title}>
                CRÉDITOS
              </Typography>
              <ReadDrawer contrasteValue={contraste} />
            </BoxFlex>
          </TopBox>
        </List>
        {/* créditos */}
        <List className={classes.ContentList}>
          {credits.map((cred, i) => {
            return (
              <>
                <ListSubheader
                  className={classes.CreditOccupation}
                  disableSticky
                >
                  {cred.function}
                </ListSubheader>
                {cred.team ? (
                  <>
                    {cred.team.map((person, personIndex) => {
                      return (
                        <ListItem key={i} className={classes.CreditTeam}>
                          <ListItemText disableTypography>
                            <Typography
                              key={personIndex}
                              variant="body1"
                              className={classes.ItemName}
                            >
                              {person.name}
                            </Typography>
                            {person.link ? (
                              <Box className={classes.HasLink}>
                                <Typography variant="body2">
                                  <a
                                    href={person.link}
                                    className={classes.Link}
                                    target="_blank"
                                    rel="noopener noreferrer"
                                  >
                                    Lattes <LinkIcon fontSize="small" />
                                  </a>
                                </Typography>
                              </Box>
                            ) : (
                              <>
                                {/* <Typography variant='body2'>
                                  Aguardando Lattes
                                </Typography> */}
                              </>
                            )}
                          </ListItemText>
                        </ListItem>
                      );
                    })}
                  </>
                ) : (
                  <></>
                )}
                <Divider />
              </>
            );
          })}
          <div className={classes.copyright}>
            <Typography variant="body2">
              © 2022. Ministério da Saúde. Sistema Universidade Aberta do SUS.
              Fundação Oswaldo Cruz & Universidade Federal do Maranhão. É
              permitida a reprodução, disseminação e utilização desta obra, em
              parte ou em sua totalidade, nos termos da licença para usuário
              final do Acervo de Recursos Educacionais em Saúde (ARES). Deve ser
              citada a fonte e é vedada sua utilização comercial, sem a
              autorização expressa dos seus autores, conf. Lei de Direitos
              Autorais – LDA (Lei n.º 9.610, de 19 de fevereiro de 1998).
            </Typography>
          </div>
        </List>
      </div>
    );
  };

  return (
    <div>
      <>
        <RoundButton type="menu" onClick={toggleDrawer(true)} tooltip="Menu" />
        <Drawer
          anchor="left"
          open={opened}
          onClose={toggleDrawer(false)}
          className="contentDrawer"
        >
          {menu ? menuList() : <></>}
          {refs ? refsList() : <></>}
          {creds ? creditsList() : <></>}
          {citar ? citarList() : <></>}
          {/* ABAIXO A GAMBI PRA PODER LER OS MENUS KK */}
        </Drawer>
      </>
    </div>
  );
};
export default forwardRef(InfoDrawer);
