import React from 'react';
import {
  Typography,
  Box,
  Dialog,
  DialogContentText,
  DialogContent,
} from '@material-ui/core';
import { CloseButton } from './styles';
import { useSelector } from 'react-redux';
import button_close from '../../../../assets/buttons/btn_fechar.svg';
import button_close_contraste from '../../../../assets/buttons/btn_fechar-contraste.png';
import themeLight from '../../../../theme/Palette/Light/palette.js';
import themeDark from '../../../../theme/Palette/Dark/palette.js';
import themeDefault from '../../../../theme';
import { makeStyles } from '@material-ui/core/styles';
import Slide from '@material-ui/core/Slide';
const Transition = React.forwardRef(function Transition(props, ref) {
  return <Slide direction='up' ref={ref} {...props} />;
});
const useStyles = makeStyles({
  Dialog: {},
  DialogTitle: {
    // background: (contraste) => theme.palette.black.white,
    background: (theme) => theme.palette.black.white,
    color: (theme) => theme.palette.white.components,
    display: 'flex',
    padding: themeDefault.spacing(2),
    '@media(min-width: 900px)': {
      padding: themeDefault.spacing(3),
    },
  },
  DialogTitleContent: {
    flexGrow: '1',
    display: 'flex',
    alignItems: 'center',
    color: (theme) => theme.palette.white.components,
    h6: {
      lineHeight: 1.1,
    },
  },
  DialogContent: {
    background: (theme) => theme.palette.black.white,
    padding: themeDefault.spacing(2),
    maxHeight: '60vh',
    overflow: 'auto',
    '@media(min-width: 900px)': {
      padding: themeDefault.spacing(3),
    },
  },
  DialogContentText: {
    color: (theme) => theme.palette.white.grey,
  },
  Divider: {
    background: (theme) => theme.palette.white.components,
    height: '2px',
  },
});

function Answer({ open, setOpen, answerValue, content }) {
  const contraste = useSelector((state) => state.contraste);
  const handleClose = () => {
    setOpen(false);
  };
  const theme = contraste ? themeDark : themeLight;
  const classes = useStyles(theme);
  return (
    <Dialog
      open={open}
      TransitionComponent={Transition}
      keepMounted
      onClose={handleClose}
      aria-labelledby='alert-dialog-slide-title'
      aria-describedby='alert-dialog-slide-description'
      maxWidth='md'
      className={classes.Dialog}
    >
      <Box id='alert-dialog-slide-title' className={classes.DialogTitle}>
        <Box className={classes.DialogTitleContent}>
          <Typography variant='h6'>{content[answerValue].value}</Typography>
        </Box>
        <CloseButton onClick={handleClose}>
          {contraste ? (
            <img src={button_close_contraste} alt='Fechar' />
          ) : (
            <img src={button_close} alt='Fechar' />
          )}
        </CloseButton>
      </Box>
      <Box className={classes.Divider} />
      <DialogContent className={classes.DialogContent}>
        <DialogContentText
          id='alert-dialog-slide-description'
          className={classes.DialogContentText}
        >
          <p>{content[answerValue].feedback}</p>
        </DialogContentText>
      </DialogContent>
    </Dialog>
  );
}

export default Answer;
