// API helper file
import ky from 'ky'
const defaultURL = 'https://lti.v2.saiteava.org/api'

const getURL = () => {
  const urlParams = new URLSearchParams(window.location.search)
  const url = urlParams.get('lti_url')
  return url
}

const getLtik = () => {
  const urlParams = new URLSearchParams(window.location.search)
  const ltik = urlParams.get('ltik')
  return ltik
}

const API = {
  getIdtoken: async () => {
    const ltik = getLtik();
    // If ltik is found, make requests to server
    if (ltik) {
      try {
        const apiURL = getURL() || defaultURL;
        const response = await ky
          .get(apiURL + '/idtoken', {
            mode: 'cors',
            credentials: 'include',
            headers: { Authorization: 'Bearer ' + ltik },
          })
          .json();
        return response;
      } catch (err) {
        console.log(err);
      }
    }
    return false;
  },
  getSufix: async () => {
    const idtoken = await API.getIdtoken();
    // If ltik is found, make requests to server
    const sufix = (idtoken && idtoken.launch.custom && idtoken.launch.custom.sufix) ? '_' + idtoken.launch.custom.sufix : '';
    return sufix
  },
  getData: async (key) => {
    let data = JSON.parse(window.sessionStorage.getItem(key));
    const ltik = getLtik();
    // If ltik is found, make requests to server
    if (ltik) {
      try {
        const apiURL = getURL() || defaultURL;
        const response = await ky
          .get(apiURL + '/data/' + key, {
            mode: 'cors',
            credentials: 'include',
            headers: { Authorization: 'Bearer ' + ltik },
          })
          .json();
        if (response) data = response;
      } catch (err) {
        console.log(err);
      }
    }
    return data;
  },  
  setData: async (key, data) => {
    const obj = {
      data: data,
      key: key,
    };
    window.sessionStorage.setItem(key, JSON.stringify(data));
    const ltik = getLtik();
    // If ltik is found, make requests to server
    if (ltik) {
      try {
        const apiURL = getURL() || defaultURL;
        await ky.post(apiURL + '/data', {
          json: obj,
          mode: 'cors',
          credentials: 'include',
          headers: { Authorization: 'Bearer ' + ltik },
        });
      } catch (err) {
        console.log(err);
      }
    }
    return true;
  },

  // sendGrade returns false if can't submit grade.
  sendGrade: async (vetor) => {
    const ltik = getLtik();
    if (!ltik) return false;
    try {
      const body = vetor;
      const apiURL = getURL() || defaultURL;
      // alterar endpoint abaixo, exemplo : '/grades/acessibilidade_unidade_1'
      const bodyResponse = await ky.post(apiURL + '/grades/colocar_endpoint_aqui', {
        json: body,
        mode: 'cors',
        credentials: 'include',
        headers: { Authorization: 'Bearer ' + ltik },
      }).json();

      return bodyResponse.scoreGiven;
    } catch (err) {
      return false;
    }
  },

//   // sendGrade returns false if can't submit grade.
//   teste: async () => {
//     console.log('testando');
//     const ltik = getLtik()
//     if (!ltik) return false
//     try {
//       const body = [1, 1]
//       const apiURL = getURL() || defaultURL;
//       console.log('antes');
//       await ky.post(apiURL + '/grades/acessibilidade_unidade_1', { json: body, mode: 'cors', credentials: 'include', headers: { Authorization: 'Bearer ' + ltik } })
//       console.log('depois');
//     } catch (err) {
//       console.log('err: ', err);
//       return false
//     }
//   }
};


export default API;
