import React, { useCallback, useEffect, useMemo, useState } from 'react';
import API from './API';

const _gereralApiKey = 'info_somativa_mariana_deficiencia';
const apiKeys = {
    answers: _gereralApiKey + '_answers',
    attempts: _gereralApiKey + '_attempts',
    lastTest: _gereralApiKey + '_last_test'
};

export const QUESTION_MODES = {
    BEFORE: 'BEFORE',
    DOING: 'DOING',
    FEEDBACK: 'FEEDBACK'
};

const initialValue = {
    mode: QUESTION_MODES.BEFORE,
    canSubmit: false,
    attemptsCount: 0,
    lastTest: null,
    setAnswer: ({ questionId, answer }) => { },
    getAnswer: ({ questionId }) => { },
    submit: async () => { },
    initQuestions: () => { },
    abortQuestions: () => { },
    goToFeedbacks: () => { },
    test: () => { }
};

export const QuestionsContext = React.createContext(initialValue);

export const QuestionsContextProvider = ({ totalQuestions, children }) => {
    const [answers, setAnswers] = useState(Array(totalQuestions).fill(0).map(_ => ''));
    const [mode, setMode] = useState(QUESTION_MODES.BEFORE);
    const [attemptsCount, setAtemptsCount] = useState(0);
    const [lastTest, setLastTest] = useState(null);

    useEffect(() => {
        const init = async () => {
            const _sufix = await API.getSufix();
            const dataAnswers = await API.getData(apiKeys.answers + _sufix);
            const dataAttempts = await API.getData(apiKeys.attempts + _sufix);
            const dataLastTest = await API.getData(apiKeys.lastTest + _sufix);
            setAnswers(dataAnswers ? dataAnswers.answers : Array(totalQuestions).fill(0).map(_ => ''));
            setAtemptsCount(dataAttempts ? dataAttempts.attempts : 0);
            setLastTest(dataLastTest ? dataLastTest.lastTest : null);
        };
        init();
    }, []);


    const setAnswer = useCallback(async ({ questionId, answer }) => {
        console.log({ questionId, answer });
        const newAnswers = [...answers];
        newAnswers[questionId - 1] = answer;
        const _sufix = await API.getSufix();
        await API.setData(apiKeys.answers + _sufix, {
            answers: newAnswers
        });
        setAnswers(newAnswers);
    }, [answers]);

    const getAnswer = useCallback(({ questionId }) => {
        try {
            return answers[questionId - 1];
        }
        catch (ex) {
            return '';
        }
    }, [answers]);

    const canSubmit = useMemo(() => answers.every(x => x !== false), [answers]);

    const submit = useCallback(async () => {
        console.log('enviando respostas: ', answers);
        const _sufix = await API.getSufix();
        const dataAnswers = await API.getData(apiKeys.answers + _sufix);
        let grade = await API.sendGrade(dataAnswers.answers);
        
        if (grade === false) {
            grade = -1;
        }
        
        const lastTest = {
            grade: grade,
            answers: dataAnswers.answers
        };

        await API.setData(apiKeys.attempts + _sufix, {
            attempts: attemptsCount + 1
        });
        await API.setData(apiKeys.lastTest + _sufix, {
            lastTest
        });
        
        setLastTest(lastTest);
        setAtemptsCount(attemptsCount + 1);
        setMode(QUESTION_MODES.FEEDBACK);
    }, [answers, attemptsCount]);

    const initQuestions = useCallback(() => {
        setAnswers(Array(totalQuestions).fill(0).map(_ => ''));
        setMode(QUESTION_MODES.DOING);
    }, [totalQuestions]);

    const abortQuestions = useCallback(() => {
        setMode(QUESTION_MODES.BEFORE);
    }, []);

    const goToFeedbacks = useCallback(() => {
        if (lastTest) {
            setAnswers(lastTest.answers);
            setMode(QUESTION_MODES.FEEDBACK);
        }
    }, [lastTest]);

    const test = useCallback(() => {
        API.teste();
    }, []);

    useEffect(() => setAnswer(Array(totalQuestions).fill('')), [totalQuestions]);
    console.log(answers);

    return (
        <QuestionsContext.Provider value={{
            setAnswer,
            getAnswer,
            canSubmit,
            submit,
            mode,
            initQuestions,
            abortQuestions,
            attemptsCount,
            goToFeedbacks,
            lastTest: lastTest,
            test
        }}>
            {children}
        </QuestionsContext.Provider>
    );
};



