import React, { useEffect, useState } from 'react';
import CssBaseline from '@material-ui/core/CssBaseline';
import Grid from '@material-ui/core/Grid';
import Router from '../../routes';
import useDefineContent from './orientationUtils';
import Swipe from 'react-easy-swipe';
// import { Button } from '@material-ui/core'

import { Provider, useSelector } from 'react-redux';
import store from '../../store';

import { Container } from './styles';
// import { FontModifierContainer } from './styles'
import { ThemeProvider as StyledProvider } from 'styled-components';
import { ThemeProvider } from '@material-ui/core/styles';

import { swipeRight, swipeLeft, usePage } from './swipe';

import { createMuiTheme } from '@material-ui/core';
import paletteLight from '../../theme/Palette/Light/palette.js';
import paletteDark from '../../theme/Palette/Dark/palette.js';
import button from '../../theme/button';
import typography from '../../theme/typography';
import typography1 from '../../theme/typographySM';
import typography2 from '../../theme/typographyBG';
import { dark } from '@material-ui/core/styles/createPalette';

const content = () => (
  <Grid id='center-container' item xs={12}>
    {' '}
    <Router />{' '}
  </Grid>
);
let defaultTheme = createMuiTheme();

export default function UI() {
  const contrasteValue = useSelector((state) => state.contraste);
  const pages = [];
  const p = usePage();
  const [currenteTheme, setTheme] = useState(typography);
  const [themeId, setThemeId] = useState(0);

  const Thema = createMuiTheme({
    ...defaultTheme,
    ...(!contrasteValue ? paletteLight : paletteDark),

    overrides: {
      ...button,
      ...currenteTheme,
    },
  });
  const ThemaMobile = createMuiTheme({
    ...defaultTheme,
    ...(!contrasteValue ? paletteLight : paletteDark),

    overrides: {
      ...button,
      ...typography,
    },
  });

  const decreaseFont = () => {
    if (themeId === 1) {
      setThemeId(0);
    } else if (themeId === 0) {
      setThemeId(-1);
    } else {
      setThemeId(1);
    }
  };

  const increaseFont = () => {
    if (themeId === 0) {
      setThemeId(1);
    } else if (themeId === -1) {
      setThemeId(0);
    } else {
      setThemeId(-1);
    }
  };
  const [bool, setBool] = useState(false);
  function handleKeyboardT(event) {
    if (event.key === '=' || event.key === '+') {
      increaseFont();
      window.removeEventListener('keydown', handleKeyboardT);
      setBool(!bool);
    } else if (event.key === '-') {
      decreaseFont();
      window.removeEventListener('keydown', handleKeyboardT);
      setBool(!bool);
    }
  }

  useEffect(() => {
    window.addEventListener('keydown', handleKeyboardT);
  }, [bool]);

  useEffect(() => {
    Thema.typography.body1.fontSize = '11rem';
    switch (themeId) {
      case 0:
        setTheme(typography);
        break;
      case -1:
        setTheme(typography1);
        break;
      case 1:
        setTheme(typography2);
        break;
      default:
        break;
    }
  }, [themeId, Thema.typography.body1.fontSize]);

  // useEffect(() => {
  //   for (const p of Router().props.children.props.children.props.children) {
  //     pages.push(p.props.path)
  //   }
  //   console.log(pages)
  // }, [pages])

  return (
    <>
      {/* <Provider store={store}> */}
      <CssBaseline />
      <StyledProvider theme={window.innerWidth >= 900 ? Thema : ThemaMobile}>
        <ThemeProvider theme={window.innerWidth >= 900 ? Thema : ThemaMobile}>
          <Container
            container
            direction='row'
            justify='center'
            alignItems='center'
          >
            <Swipe
              onSwipeLeft={() => swipeLeft(p.currentPage, p.setPage, pages)}
              onSwipeRight={() => swipeRight(p.currentPage, p.setPage, pages)}
              className='w-100 h-100'
            >
              {useDefineContent(content)}
              {/* <FontModifierContainer>
                  <Button
                    color='aaa'
                    onClick={() => {
                      decreaseFont()
                    }}
                  >
                    A-
                  </Button>
                  <Button
                    color='aaa'
                    onClick={() => {
                      increaseFont()
                    }}
                  >
                    A+
                  </Button>
                </FontModifierContainer> */}
            </Swipe>
          </Container>
        </ThemeProvider> 
      </StyledProvider>
      {/* </Provider> */}
    </>
  );
}
