import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import { Content, StyledSection, SectionImage } from "./styles";

import IMG from "./../../assets/images/Pg-12-Img-1.png";
import btnParaSaber from "../../assets/images/btnParaSaberMais.png";
import Reference from "../../components/Reference";
import Dialog from "../../components/Dialog";

export default function () {
	const [refNumber, setRefNumber] = useState(0);
	const [openDrawer, setOpenDrawer] = useState(false);

	const handleOpenDrawer = (value) => {
		setRefNumber(value);
		setOpenDrawer(!openDrawer);
	};

	return (
		<DefaultPage
			title="Insuficiência cardíaca"
			refNumber={refNumber}
			openDrawer={openDrawer}
			prev="_9"
			next="/_11"
			replay="/"
			titleCenter
		>
			<Content>
				<StyledSection>
					<SectionImage>
						<img alt="" className="img-fluid" src={IMG} />
					</SectionImage>
					<Box className="left" display="flex" flexDirection="column">
						<Typography variant="body1" paragraph="true">
							Dona Marilene relata dispneia aos esforços, ortopneia (dormia com
							três travesseiros por conta da falta de ar), o que é compatível
							com dispneia paroxística noturna (DPN), em que ela dizia acordar
							no meio da noite com sensação de sufocação, sendo obrigada a
							sentar-se para melhorar. Além disso, ao exame físico, apresentava
							estertores crepitantes pulmonares, edema de tornozelos, distensão
							venosa jugular (estase jugular) e refluxo hepatojugular positivo
							(observação de aumento da coluna de sangue da veia jugular após
							compressão da região hepática)
							<Reference
								num="13"
								onClick={() => {
									handleOpenDrawer(13);
								}}
							/>
							.
						</Typography>
						<Box className="colored-box" padding="10px" borderRadius="10px">
							<Typography variant="body1">
								Com esse quadro, já há a presença de quatro critérios maiores e
								dois critérios menores, de acordo com os critérios diagnósticos
								de Framingham apresentados na página anterior, configurando o
								diagnóstico de insuficiência cardíaca. No contexto da
								hipertensão arterial sistêmica, a insuficiência cardíaca, que é
								uma síndrome de caráter multifatorial e insidioso considerada
								via final comum da maioria das doenças cardíacas, é considerada
								como uma lesão de órgão-alvo
								<Reference
									num="1"
									onClick={() => {
										handleOpenDrawer(1);
									}}
									alternative
								/>
								.
							</Typography>
						</Box>
					</Box>
				</StyledSection>
				<Box className="dialog">
					<Dialog
						title="Para saber mais"
						image={btnParaSaber}
						content={
							<>
								Além dos critérios diagnósticos de Framingham, a Linha de
								Cuidado para Insuficiência Cardíaca (IC) no adulto
								<Reference
									num="12"
									onClick={() => {
										handleOpenDrawer(12);
									}}
								/>{" "}
								apresenta o score de risco de Boston para classificação da
								probabilidade de desenvolver insuficiência cardíaca, que também
								pode ser utilizado, a critério do profissional. Para saber mais,
								acesse:{" "}
								<a
									href="https://linhasdecuidado.saude.gov.br/portal/insuficiencia-cardiaca-(IC)-no-adulto/atencao-especializada/avaliacao-inicial/#Diagnostico&#pills-criterios-diagnosticos"
									target="_blank"
								>
									Insuficiência cardíaca no adulto
								</a>
							</>
						}
					/>
				</Box>
			</Content>
		</DefaultPage>
	);
}
