import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import {
  Content,
  DivGrid,
  Div,
  DivTable,
  SectionInnerTable,
  SectionTable,
  TableElement,
  TableWrapper,
  TableHeader,
  DivGridWrapper,
  TableFooter,
} from "./styles";
import Reference from "../../components/Reference";
import {
  column1,
  column2,
  column3,
  column4,
  column5,
  column6,
  column7,
} from "./data";
export default function () {
  const [refNumber, setRefNumber] = useState(0);
  const [openDrawer, setOpenDrawer] = useState(false);

  const handleOpenDrawer = (value) => {
    setRefNumber(value);
    setOpenDrawer(!openDrawer);
  };

  const t_1 = (
    <>
      <ul>
        <li>Desconforto ou dor retroesternal;</li>
        <li>Desencadeada pelo exercício;</li>
        <li>Aliviada com repouso ou uso de nitroglicerina.</li>
      </ul>
    </>
  );
  const t_2 = (
    <>
      <ul>
        <li>Presença de apenas dois dos fatores anteriores.</li>
      </ul>
    </>
  );
  const t_3 = (
    <>
      <ul>
        <li>Presença de apenas um ou nenhum dos fatores anteriores.</li>
      </ul>
    </>
  );

  const divs = [
    {
      id: 0,
      label: "Angina típica",
      target: t_1,
      visited: false,
    },
    {
      id: 1,
      label: "Angina atípica",
      target: t_2,
      visited: false,
    },
    {
      id: 2,
      label: "Dor torácica não anginosa",
      target: t_3,
      visited: false,
    },
  ];

  const [text, setText] = useState(t_1);
  const [visited, setVisited] = useState([true, false, false]);
  const handleVisit = (id) => {
    let aux = visited;
    for (let i = 0; i < aux.length; i++) {
      if (i === id) {
        aux[i] = true;
      } else {
        aux[i] = false;
      }
    }
    setVisited(aux);
  };
  return (
    <DefaultPage
      title="Dor torácica angionosa"
      refNumber={refNumber}
      openDrawer={openDrawer}
      prev="/_10"
      next="/_12"
      replay="/"
      titleCenter
    >
      <Content>
        <Box className="text">
          <Typography variant="body1" paragraph="true">
            É uma dor que apresenta as características típicas de dor de origem
            cardíaca. É uma das manifestações mais comuns da Doença Arterial
            Coronariana (DAC). Normalmente, se inicia ou piora com esforço
            físico e é atenuada com repouso ou uso de nitroglicerina e
            derivados. Isso não lembra a dor da Marilene?{" "}
            <strong>Clique</strong> nas abas abaixo para conhecer a
            classificação da dor torácica de acordo com suas características.
            Observe, ao lado, uma tabela que correlaciona a dor com a
            probabilidade de o paciente apresentar doença coronariana.
          </Typography>
        </Box>
        <DivTable>
          <DivGridWrapper>
            <DivGrid>
              {divs.map((element) => {
                return (
                  <Div
                    onClick={() => {
                      setText(element.target);
                      handleVisit(element.id);
                    }}
                    visited={visited[element.id]}
                  >
                    <Typography variant="body1">{element.label}</Typography>
                  </Div>
                );
              })}
            </DivGrid>
            <Box
              display="flex"
              width="100%"
              borderRadius="15px"
              padding="1.25rem"
              className="colored-border"
              marginBottom="16px"
            >
              <Typography variant="body1" className="text">
                {text}
              </Typography>
            </Box>
          </DivGridWrapper>
          <TableWrapper>
            <TableHeader>
              <TableElement>
                <Typography variant="gridFont">Idade</Typography>
              </TableElement>
              <TableElement>
                <Typography variant="gridFont">
                  Dor torácica não anginosa
                </Typography>
              </TableElement>
              <TableElement>
                <Typography variant="gridFont">Angina atípica</Typography>
              </TableElement>
              <TableElement>
                <Typography variant="gridFont"> Angina típica</Typography>
              </TableElement>
            </TableHeader>
            <SectionTable>
              <SectionInnerTable>
                {column1.map((elem) => {
                  return <TableElement elem={elem}>{elem}</TableElement>;
                })}
              </SectionInnerTable>
              <SectionInnerTable>
                {column2.map((elem) => {
                  return <TableElement elem={elem}>{elem}</TableElement>;
                })}
              </SectionInnerTable>
              <SectionInnerTable>
                {column3.map((elem) => {
                  return <TableElement elem={elem}>{elem}</TableElement>;
                })}
              </SectionInnerTable>
              <SectionInnerTable>
                {column4.map((elem) => {
                  return <TableElement elem={elem}>{elem}</TableElement>;
                })}
              </SectionInnerTable>
              <SectionInnerTable>
                {column5.map((elem) => {
                  return <TableElement elem={elem}>{elem}</TableElement>;
                })}
              </SectionInnerTable>
              <SectionInnerTable>
                {column6.map((elem) => {
                  return <TableElement elem={elem}>{elem}</TableElement>;
                })}
              </SectionInnerTable>
              <SectionInnerTable>
                {column7.map((elem) => {
                  return <TableElement elem={elem}>{elem}</TableElement>;
                })}
              </SectionInnerTable>
            </SectionTable>
            <TableFooter>
              <TableElement border="none !important">
                Fonte: Adaptada de Diamond e Forrester
                <Reference
                  num="7"
                  onClick={() => {
                    handleOpenDrawer(7);
                  }}
                ></Reference>
              </TableElement>
            </TableFooter>
          </TableWrapper>
        </DivTable>
      </Content>
    </DefaultPage>
  );
}
