import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import { Content, StyledSection, SectionImage, TextWrapper } from "./styles";
import ContourBox from "../../components/ContourBox";
import IMG from "./../../assets/images/Pg-5-Img-1.png";
import Reference from "../../components/Reference";

export default function () {
  const [refNumber, setRefNumber] = useState(0);
  const [openDrawer, setOpenDrawer] = useState(false);

  const handleOpenDrawer = (value) => {
    setRefNumber(value);
    setOpenDrawer(!openDrawer);
  };

  return (
    <DefaultPage
      title="Descompensação aguda de Hipertensão Arterial Sistêmica – caso norteador"
      refNumber={refNumber}
      openDrawer={openDrawer}
      prev="_13"
      next="/_15"
      replay="/"
      titleCenter
    >
      <Content>
        <Box className="text" style={{ gap: "1rem" }}>
          <Typography variant="body1">
            Em situações com alto risco de eventos cardiovasculares iminentes,
            como aqueles com doenças da aorta ou aneurismas cerebrais, deve-se
            reduzir a pressão arterial no momento do atendimento, em horas.
          </Typography>

          <ContourBox>
            <Typography variant="body1">
              Para isso, pode-se utilizar medicações orais, como captopril, que
              tem uma meia-vida curta. O uso da nifedipina, especialmente
              sublingual, não é recomendado, pois reduz rapidamente a pressão
              arterial, podendo desencadear um Acidente Vascular Encefálico,
              entre outros problemas
              <Reference
                num="10, "
                onClick={() => {
                  handleOpenDrawer(10);
                }}
              />
              <Reference
                num="11"
                onClick={() => {
                  handleOpenDrawer(11);
                }}
              />
              .
            </Typography>
          </ContourBox>
          <StyledSection>
            <SectionImage>
              <img alt="" className="img-fluid" src={IMG} />
            </SectionImage>
            <TextWrapper>
              <Typography variant="body1" className="text">
                É interessante notar que, no caso de Marilene, embora não seja o
                foco do nosso estudo, seria importante iniciar abordagem para
                doença isquêmica crônica do coração, dada a alta probabilidade
                desse diagnóstico. Essa abordagem, além de medicamentosa, deve
                contar com atuação multiprofissional para atenuação dos fatores
                de risco.
              </Typography>
            </TextWrapper>
          </StyledSection>
        </Box>
      </Content>
    </DefaultPage>
  );
}
