import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import { Content, DivGrid, Div } from "./styles";
import Reference from "../../components/Reference";

export default function () {
  const [refNumber, setRefNumber] = useState(0);
  const [openDrawer, setOpenDrawer] = useState(false);

  const handleOpenDrawer = (value) => {
    setRefNumber(value);
    setOpenDrawer(!openDrawer);
  };

  const t_1 = (
    <>
      A anamnese deve investigar: <br />
      <ul>
        <li>
          Tempo de diagnóstico e gravidade da Hipertensão Arterial Sistêmica;
        </li>
        <li>Diagnóstico de lesão prévia de órgão-alvo;</li>
        <li>
          Uso de anti-hipertensivos, adesão ao tratamento, os hábitos do
          cotidiano e controle da pressão arterial;
        </li>
        <li>
          Uso de medicações ou outras substâncias que possam causar elevação da
          pressão arterial;
        </li>
        <li>
          Presença de sintomas específicos que possam ser sugestivos de
          comprometimento de órgãos-alvo: dor torácica (isquemia miocárdica),
          dorsalgia ou lombalgia (dissecção de aorta), dispneia (insuficiência
          cardíaca), sintomas neurológicos focais, cefaleia, convulsões e
          alterações do nível de consciência (Acidente Vascular Encefálico ou
          hemorragia subaracnoidea).
        </li>
      </ul>
    </>
  );
  const t_2 = (
    <>
      O exame físico deve contemplar: <br />
      <ul>
        <li>Aferição da pressão arterial com técnica e aparelho adequados;</li>
        <li>
          Avaliação cardiopulmonar: medir pulsos; verificar se há alterações na
          ausculta (presença de terceira bulha), procurar sinais de
          insuficiência cardíaca (estase jugular, B3, ictus desviado,
          hepatomegalia, edema de membros inferiores, estertores crepitantes
          pulmonares);
        </li>
        <li>
          Abdome: observar sopros abdominais, massas pulsáteis e presença de
          hepatomegalia;
        </li>
        <li>
          Exame neurológico: avaliação do nível de consciência e orientação,
          sinais de irritação meníngea e sinais neurológicos focais.
        </li>
      </ul>
    </>
  );

  const divs = [
    {
      id: 0,
      label: "Anamnese",
      target: t_1,
      visited: false,
    },
    {
      id: 1,
      label: "Exame físico",
      target: t_2,
      visited: false,
    },
  ];

  const [text, setText] = useState(t_1);
  const [visited, setVisited] = useState([true, false]);

  const handleVisit = (id) => {
    let aux = visited;
    for (let i = 0; i < aux.length; i++) {
      if (i === id) {
        aux[i] = true;
      } else {
        aux[i] = false;
      }
    }
    setVisited(aux);
  };
  return (
    <DefaultPage
      title="Descompensação aguda de Hipertensão Arterial Sistêmica – caso norteador"
      refNumber={refNumber}
      openDrawer={openDrawer}
      prev="/_14"
      next="/_16"
      replay="/"
      titleCenter
    >
      <Content>
        <Box className="text">
          <Typography variant="body1" paragraph="true">
            Dada a importância da realização de anamnese e exame físico
            adequados, vamos sistematizar quais dados não podem faltar nessa
            avaliação
            <Reference
              num="10"
              onClick={() => {
                handleOpenDrawer(10);
              }}
            />
            (<strong>clique</strong> nos botões abaixo):
          </Typography>
        </Box>
        <DivGrid>
          {divs.map((element) => {
            return (
              <Div
                visited={visited[element.id]}
                onClick={() => {
                  handleVisit(element.id);
                  setText(element.target);
                }}
              >
                <Typography variant="body1" align="center">
                  {element.label}
                </Typography>
              </Div>
            );
          })}
        </DivGrid>
        <Box
          display="flex"
          width="100%"
          borderRadius="15px"
          padding="1rem"
          marginBottom="16px"
          className="colored-box"
        >
          <Typography variant="body1" className="text">
            {text}
          </Typography>
        </Box>
      </Content>
    </DefaultPage>
  );
}
