import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import { Content, NumberSection, TargetText, Numbers, Number } from "./styles";
import OBJETIVO from "./../../assets/images/OBJETIVO.png";
import important from "../../assets/icons/ATENCAO.png";
import Attention from "../../components/Attention";
import Reference from "../../components/Reference";
export default function () {
	const [refNumber, setRefNumber] = useState(0);
	const [openDrawer, setOpenDrawer] = useState(false);

	const handleOpenDrawer = (value) => {
		setRefNumber(value);
		setOpenDrawer(!openDrawer);
	};
	const btns = [
		{
			label: 0,
			target: (
				<>
					Isso compreende a oferta de cuidados abrangentes, incluindo a promoção
					da saúde, a prevenção primária, o rastreamento e a detecção precoce de
					doenças (prevenção secundária), a reabilitação e os cuidados
					paliativos (prevenção terciária), além da prevenção de intervenções e
					danos desnecessários, a chamada prevenção quaternária.
				</>
			),
			visited: false,
		},
		{
			label: 1,
			target: (
				<>
					Dessa maneira, o alcance da integralidade na Atenção Primária à Saúde
					pressupõe a superação do modelo restrito a ações programáticas por
					meio da criação de um modelo ampliado, com desenvolvimento de ações
					abrangentes e de acordo com as necessidades de saúde dos usuários
					<Reference
						alternative
						num="18,"
						onClick={() => {
							handleOpenDrawer(18);
						}}
					/>
					<Reference
						alternative
						num="19"
						onClick={() => {
							handleOpenDrawer(19);
						}}
					/>
					.
				</>
			),
			visited: false,
		},
		{
			label: 2,
			target: (
				<>
					Nesse contexto, o trabalho em equipe é fundamental. É importante
					ressaltar que todos os profissionais das equipes que trabalham na
					Atenção Primária podem e devem realizar ações de educação em saúde,
					contribuindo para a prevenção. A hipertensão arterial é uma condição
					que requer atuação multiprofissional e interdisciplinar, incluindo o
					paciente e seus familiares na definição e pactuação de metas de
					tratamento.
				</>
			),
			visited: false,
		},
		{
			label: 3,
			target: (
				<>
					Em casos em que sejam detectados níveis limítrofes de pressão
					arterial, é importante trabalhar o processo de educação para prevenção
					primária da hipertensão, por meio de estímulo à adoção de hábitos de
					vida saudáveis e do controle dos fatores de risco, como obesidade,
					abuso de álcool, tabagismo e excesso de ingesta de sal.
				</>
			),
			visited: false,
		},
	];
	const [content, setContent] = useState(btns[0].target);
	const [visited, setVisited] = useState([true, false, false, false]);

	const visit = (index) => {
		if (index === 0) {
			setVisited([true, false, false, false]);
		}
		if (index === 1) {
			setVisited([false, true, false, false]);
		}
		if (index === 2) {
			setVisited([false, false, true, false]);
		}
		if (index === 3) {
			setVisited([false, false, false, true]);
		}
	};

	return (
		<DefaultPage
			title="Identificação da relação com o trabalho do usuário e medidas de promoção e prevenção"
			refNumber={refNumber}
			openDrawer={openDrawer}
			prev="/_16"
			next="/_18"
			replay="/"
			titleCenter
		>
			<Content>
				<Box className="text">
					<Typography variant="body1" paragraph="true">
						Nos serviços de saúde, é fundamental que a atenção à saúde dos
						usuários se expresse sob a ótica da clínica ampliada, com a oferta
						de cuidado à pessoa e com a sua participação, e não com foco apenas
						em seu adoecimento.
					</Typography>
					<Typography variant="body1" paragraph="true">
						<strong>Clique</strong> nos botões numerados abaixo para entender um
						pouco mais sobre o contexto de atenção ampliada ao usuário:
					</Typography>
				</Box>
				<NumberSection>
					<Numbers>
						{btns.map((element) => {
							return (
								<Number
									onClick={() => {
										setContent(element.target);
										visit(element.label);
									}}
									visited={visited[element.label]}
								>
									<Typography variant="body1">{element.label + 1}</Typography>
								</Number>
							);
						})}
					</Numbers>
					<TargetText>
						<Typography variant="body1">{content}</Typography>
					</TargetText>
				</NumberSection>
				<Attention image={important} title="IMPORTANTE">
					É válido ressaltar que a abordagem da Hipertensão Arterial Sistêmica
					com objetivo de reduzir morbimortalidade cardiovascular deve ocorrer
					em nível populacional, através de políticas públicas para a redução do
					consumo de álcool e tabaco e para a prática de atividades físicas por
					meio de oferta de locais públicos para isso, como as chamadas
					Academias ao Ar Livre, entre outras ações.
				</Attention>
			</Content>
		</DefaultPage>
	);
}
