import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import Reference from "./../../components/Reference";
import {
	ColoredBox,
	Content,
	StyledSection,
	SectionImage,
	BTN1,
	BTN2,
	BTN3,
} from "./styles";
import IMG_SECTION from "./../../assets/images/Pg-4-Img-1.png";

import { withStyles } from "@material-ui/core/styles";
import Button from "@material-ui/core/Button";
import Dialog from "@material-ui/core/Dialog";
import MuiDialogTitle from "@material-ui/core/DialogTitle";
import MuiDialogContent from "@material-ui/core/DialogContent";
import MuiDialogActions from "@material-ui/core/DialogActions";
import IconButton from "@material-ui/core/IconButton";
import CloseIcon from "@material-ui/icons/Close";

const styles = (theme) => ({
	root: {
		margin: 0,
		padding: theme.spacing(2),
	},
	closeButton: {
		position: "absolute",
		right: theme.spacing(1),
		top: theme.spacing(1),
		color: theme.palette.grey[500],
	},
});

const DialogTitle = withStyles(styles)((props) => {
	const { children, classes, onClose, ...other } = props;
	return (
		<MuiDialogTitle disableTypography className={classes.root} {...other}>
			<Typography variant="h6">{children}</Typography>
			{onClose ? (
				<IconButton
					aria-label="close"
					className={classes.closeButton}
					onClick={onClose}
				>
					<CloseIcon />
				</IconButton>
			) : null}
		</MuiDialogTitle>
	);
});

const DialogContent = withStyles((theme) => ({
	root: {
		padding: theme.spacing(2),
	},
}))(MuiDialogContent);

const DialogActions = withStyles((theme) => ({
	root: {
		margin: 0,
		padding: theme.spacing(1),
	},
}))(MuiDialogActions);

export default function () {
	const [refNumber, setRefNumber] = useState(0);
	const [openDrawer, setOpenDrawer] = useState(false);

	const handleOpenDrawer = (value) => {
		setRefNumber(value);
		setOpenDrawer(!openDrawer);
	};

	const [open, setOpen] = React.useState(false);

	const content = [
		{
			title: <strong>Recomendações prévias</strong>,
			body: (
				<ul>
					<li>
						<Typography variant="body1" paragraph="true">
							Evitar grandes refeições, o uso de cigarros e de bebidas com
							cafeína nos 30 minutos precedentes;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A medição deve ocorrer após cinco minutos de repouso em ambiente
							calmo;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Instruir a não conversar durante a mediação;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A bexiga deve estar vazia;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Deve-se evitar a medida da PA em situações de estresse físico
							(dor) e emocional;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A hipertensão do avental branco pode ser uma limitação, em que as
							medidas no consultório médico são mais elevadas do que a média
							habitual de pressão;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A Automedida da Pressão Arterial (ampa) tem a vantagem de ser
							feita no ambiente em que o usuário passa a maior parte do tempo,
							mas os aparelhos semiautomáticos muitas vezes apresentam problemas
							de calibração. Na suspeita de hipertensão do avental branco ou
							hipertensão mascarada, há a possibilidade de ser realizada uma
							Monitorização Ambulatorial de Pressão Arterial (MAPA), por meio de
							aparelhos validados que empregam o método oscilométrico, em que a
							pressão é aferida diversas vezes em 24 horas, inclusive no sono
							<Reference
								num="1, "
								onClick={() => {
									handleOpenDrawer(1);
								}}
							/>
							<Reference
								num="2"
								onClick={() => {
									handleOpenDrawer(2);
								}}
							/>
							.
						</Typography>
					</li>
				</ul>
			),
		},
		{
			title: <strong>Em relação ao manguito</strong>,
			body: (
				<ul>
					<li>
						<Typography variant="body1" paragraph="true">
							A câmara inflável (cuff) do manguito deve ser adequada para a
							circunferência do braço;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A largura deve ser pelo menos 40% do comprimento do braço
							(distância entre o olécrano e o acrômio) e o comprimento de pelo
							menos 80% de sua circunferência;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A câmara inflável deve cobrir pelo menos dois terços da
							circunferência do braço;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Dimensões adequadas do manguito: há uma tendência de se
							superestimar os valores pressóricos de indivíduos com braço de
							circunferência maior que a recomendada para o manguito, e o
							inverso também ocorre;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Atentar para a calibração adequada dos aparelhos{" "}
							<Reference
								num="1, "
								onClick={() => {
									handleOpenDrawer(1);
								}}
							/>
							<Reference
								num="2"
								onClick={() => {
									handleOpenDrawer(2);
								}}
							/>
							.
						</Typography>
					</li>
				</ul>
			),
		},
		{
			title: <strong>Técnica</strong>,
			body: (
				<ul>
					<li>
						<Typography variant="body1" paragraph="true">
							A pessoa deve estar sentada, com as pernas descruzadas, pés
							apoiados no chão, dorso recostado na cadeira e relaxado;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							O braço deve estar na altura do coração, apoiado, com a palma da
							mão voltada para cima, e as roupas não devem garrotear o membro;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Estimar o nível da PAS, através da palpação do pulso radial;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Palpar o pulso braquial, colocar a campânula ou diafragma do
							estetoscópio sem compreensão excessiva e inflar o manguito até 20
							e 30 mmHg acima do valor em que o pulso não for palpável;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Desinflar o manguito lentamente (2 a 4 mmHg por segundo);
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A pressão sistólica correspondente ao valor em que começarem a ser
							ouvidos os ruídos de Korotkoff;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							A pressão diastólica correspondente ao desaparecimento dos
							batimentos;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Registrar valores com intervalos de 2 mmHg, evitando-se
							arredondamentos (por exemplo: 135/85 mmHg);
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Considerar a média de duas aferições como pressão arterial do dia,
							se os valores observados diferirem em mais de 5 mmHg, medir
							novamente;
						</Typography>
					</li>
					<li>
						<Typography variant="body1" paragraph="true">
							Na primeira vez, medir a pressão nos dois braços; se discrepantes,
							considerar o valor mais alto; nas vezes subsequentes, medir no
							mesmo braço (o direito, de preferência){" "}
							<Reference
								num="1, "
								onClick={() => {
									handleOpenDrawer(1);
								}}
							/>
							<Reference
								num="2"
								onClick={() => {
									handleOpenDrawer(2);
								}}
							/>
							.
						</Typography>
					</li>
				</ul>
			),
		},
	];
	const [currentBody, setBody] = React.useState(content[0].body);
	const [currentTitle, setTitle] = React.useState(content[0].title);

	const handleClickOpen = (value) => {
		if (value != null) {
			setBody(content[value].body);
			setTitle(content[value].title);
		}
		setOpen(true);
	};
	const handleClose = () => {
		setOpen(false);
	};

	return (
		<DefaultPage
			title="Definições e diagnóstico de Hipertensão Arterial Sistêmica"
			refNumber={refNumber}
			openDrawer={openDrawer}
			next="/_4"
			prev="/_2"
			replay="/"
			titleCenter
		>
			<Content>
				<Box className="text">
					<Typography variant="body1" paragraph="true">
						O caso em questão é oportuno para relembrar o diagnóstico de
						hipertensão arterial.
					</Typography>
				</Box>
				<StyledSection>
					<Box className="d-flex flex-column w-100 w-sm-50 pr-sm-5">
						<ColoredBox>
							<Typography variant="body1" paragraph="true">
								O diagnóstico se estabelece quando existe elevação sustentada
								dos níveis pressóricos de PAS ≥ 140 mmHg e/ou PAD ≥ 90 mmHg,
								verificada em pelo menos três dias diferentes, com intervalo
								mínimo de uma semana entre as medidas. É muito importante que o
								profissional de saúde esteja atento para a realização de um
								diagnóstico correto, uma vez que se trata de uma condição
								crônica, que acompanhará o paciente por toda a sua vida. Deve-se
								evitar verificar a pressão arterial em situações em que se
								espera uma elevação da pressão mesmo em pessoas hígidas, como
								dor, luto, ansiedade, cansaço físico, entre outras, para evitar
								falsos diagnósticos.
							</Typography>
						</ColoredBox>
						<Box className="text">
							<Typography variant="body1">
								Além disso, é importante atentar para as condições em que está
								sendo medida a pressão arterial. <strong>Clique</strong> nos
								botões da imagem ao lado para conhecer as recomendações prévias,
								os cuidados em relação ao manguito e a técnica aplicada na
								aferição da pressão arterial.
							</Typography>
						</Box>
					</Box>

					<SectionImage>
						<BTN1 onClick={() => handleClickOpen(0)}>
							<Typography variant="body1">1</Typography>
						</BTN1>
						<BTN2 onClick={() => handleClickOpen(1)}>
							<Typography variant="body1">2</Typography>
						</BTN2>
						<BTN3 onClick={() => handleClickOpen(2)}>
							<Typography variant="body1">3</Typography>
						</BTN3>
						<img
							style={{ opacity: "0" }}
							className="img-fluid"
							src={IMG_SECTION}
							alt=" Carlos aferindo a pressão arterial de Marilene"
						/>
					</SectionImage>
				</StyledSection>
			</Content>
			<Dialog
				onClose={handleClose}
				aria-labelledby="customized-dialog-title"
				open={open}
			>
				<DialogTitle id="customized-dialog-title" onClose={handleClose}>
					{currentTitle}
				</DialogTitle>
				<DialogContent dividers>
					<Typography gutterBottom>{currentBody}</Typography>
				</DialogContent>
			</Dialog>
		</DefaultPage>
	);
}
