import React, { useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import Reference from "../../components/Reference";
import { ColoredBox, Content, StyledSection } from "./styles";

const styles = (theme) => ({
	root: {
		margin: 0,
		padding: theme.spacing(2),
	},
	closeButton: {
		position: "absolute",
		right: theme.spacing(1),
		top: theme.spacing(1),
		color: theme.palette.grey[500],
	},
});

export default function () {
	const [refNumber, setRefNumber] = useState(0);
	const [openDrawer, setOpenDrawer] = useState(false);

	const handleOpenDrawer = (value) => {
		setRefNumber(value);
		setOpenDrawer(!openDrawer);
	};

	return (
		<DefaultPage
			title="Definições e diagnóstico de Hipertensão Arterial Sistêmica"
			refNumber={refNumber}
			openDrawer={openDrawer}
			next="/_5"
			prev="/_4"
			replay="/"
			titleCenter
		>
			<Content>
				<Box className="text">
					<Typography variant="body1" paragraph="true">
						Recentemente, a American Heart Association (AHA) publicou novas
						Diretrizes que mudaram a definição de hipertensão arterial sistêmica
						e passaram a considerar hipertensos indivíduos com PA > 130x80 mmHg
						<Reference
							num="2, "
							onClick={() => {
								handleOpenDrawer(2);
							}}
						/>
						<Reference
							num="3"
							onClick={() => {
								handleOpenDrawer(3);
							}}
						/>
						.
					</Typography>
				</Box>
				<StyledSection>
					<Box className="d-flex flex-column w-100 w-sm-50 pr-sm-5">
						<ColoredBox>
							<Typography variant="body1" paragraph="true">
								As estimativas são de que, com essa mudança nos valores, cerca
								de 46% dos adultos norte-americanos, o que corresponde a mais 30
								milhões de pessoas, passariam a ser rotuladas como hipertensas
								somente nesse país. Essa recomendação é bastante controversa
								devido à falta de evidências científicas que sustentem o
								benefício de tratar pessoas com valores mais baixos de pressão
								<Reference
									num="2, "
									onClick={() => {
										handleOpenDrawer(2);
									}}
									color="#fff"
								/>
								<Reference
									num="4, "
									onClick={() => {
										handleOpenDrawer(4);
									}}
									color="#fff"
								/>
								<Reference
									num="5"
									onClick={() => {
										handleOpenDrawer(5);
									}}
									color="#fff"
								/>{" "}
								e porque subestima o risco de efeitos adversos do tratamento e
								do sobrediagnóstico de hipertensão. Além disso, é importante
								considerar o apoio da indústria farmacêutica para essa diretriz,
								o que pode influenciar a recomendação dos especialistas
								<Reference
									num="2, "
									onClick={() => {
										handleOpenDrawer(2);
									}}
									color="#fff"
								/>
								<Reference
									num="6"
									onClick={() => {
										handleOpenDrawer(6);
									}}
									color="#fff"
								/>
								.
							</Typography>
						</ColoredBox>
						<Box className="text">
							<Typography variant="body1">
								A American Academy of Family Physicians decidiu não apoiar tais
								diretrizes7, mantendo apoio à Joint National Committee (JNC)
								<Reference
									num="8"
									onClick={() => {
										handleOpenDrawer(8);
									}}
								/>
								, bem representada por médicos da atenção primária à saúde e
								comtendência oposta, seguindo o que se tem de evidências
								científicas e derecomendações menos invasivas, como, por
								exemplo, apenas introduzir anti-hipertensivos para pacientes de
								baixo risco cardiovascular com mais de 60 anos em casos nos
								quais a pressão esteja maior do que 150x90 mmHg
								<Reference
									num="2, "
									onClick={() => {
										handleOpenDrawer(2);
									}}
								/>
								<Reference
									num="8, "
									onClick={() => {
										handleOpenDrawer(8);
									}}
								/>
								<Reference
									num="9"
									onClick={() => {
										handleOpenDrawer(9);
									}}
								/>
								.
							</Typography>
						</Box>
					</Box>
				</StyledSection>
			</Content>
		</DefaultPage>
	);
}
