import React, { useCallback, useState } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import { Content, DivGrid, Div } from "./styles";
import Reference from "../../components/Reference";

export default function () {
	const [refNumber, setRefNumber] = useState(0);
	const [openDrawer, setOpenDrawer] = useState(false);

	const handleOpenDrawer = (value) => {
		setRefNumber(value);
		setOpenDrawer(!openDrawer);
	};

	const t_1 = (
		<>
			São situações nas quais há risco de alguma complicação clínica associada
			ao aumento abrupto dos níveis pressóricos. Nesse conceito estão
			compreendidas as urgências e as emergências hipertensivas.
		</>
	);
	const t_2 = (
		<>
			São condições em que há elevação significativa da pressão arterial, em
			geral pressão arterial diastólica ≥ 120 mmHg, com condição clínica
			estável, sem lesão de órgão-alvo aguda, mas em que existe risco potencial
			de ocorrer alguma lesão aguda. Em se tratando de pacientes que já
			apresentam alguma lesão de órgão-alvo, deve-se ficar mais atento, pois
			eles apresentam risco mais elevado de novas complicações em curto prazo,
			se não houver controle da pressão arterial. Nos casos de urgência, a
			atuação sobre o controle pressórico deve ser realizada em até 24 horas,
			com medicações por via oral
			<Reference num="10, " onClick={() => handleOpenDrawer(10)} />
			<Reference num="11" onClick={() => handleOpenDrawer(11)} />.
		</>
	);
	const t_3 = (
		<>
			São condições clínicas sintomáticas em que ocorre elevação acentuada da
			pressão arterial, tipicamente com pressão arterial diastólica ≥ 120 mmHg,
			com lesão aguda e progressiva de órgãos-alvo, com risco iminente de morte.
			Elas requerem redução imediata da pressão arterial, embora não
			necessariamente para níveis normais. Tais emergências devem ser tratadas
			com anti-hipertensivos parenterais em unidades de emergência. Ao se
			deparar com uma dessas situações, o profissional da Atenção Primária
			deverá chamar o serviço de transferência de urgência para a remoção do
			paciente imediatamente
			<Reference num="10, " onClick={() => handleOpenDrawer(10)} />
			<Reference num="11" onClick={() => handleOpenDrawer(11)} />.
		</>
	);
	const t_4 = (
		<>
			São situações em que a elevação da pressão arterial é ocasionada por algum
			desconforto (tontura, mal-estar), dor, crise de ansiedade ou pânico,
			situações de risco ou violência, ou por uma conjunção desses fatores.
			Nesses tipos de casos, não se pode estabelecer que os sintomas
			relacionados ao desconforto foram ocasionados pelo aumento da pressão
			arterial. Trata-se de uma condição muito comum, provavelmente responsável
			pela maior procura de atendimentos em unidades de urgência por elevação da
			pressão. É fundamental, nesses casos, realizar uma abordagem humanizada
			para compreensão da condição e utilizar sintomáticos (analgésicos,
			benzodiazepínicos etc.) e não anti-hipertensivos para o tratamento
			<Reference num="10" onClick={() => handleOpenDrawer(10)} />.
		</>
	);
	const t_5 = (
		<>
			São situações em que há apenas o aumento da pressão arterial dos
			pacientes, sem queixas ou riscos maiores associados. São achados nas
			verificações de rotina nas unidades de saúde da APS
			<Reference num="10" onClick={() => handleOpenDrawer(10)} />.
		</>
	);

	const divs = [
		{
			id: 0,
			label: "Crises Hipertensivas",
			target: t_1,
			visited: false,
		},
		{
			id: 1,
			label: "Urgências hipertensivas",
			target: t_2,
			visited: false,
		},
		{
			id: 2,
			label: "Emergências Hipertensivas",
			target: t_3,
			visited: false,
		},
		{
			id: 3,
			label: "Pseudocrises Hipertensivas",
			target: t_4,
			visited: false,
		},
		{
			id: 4,
			label: "Elevação eventual do nível pressórico",
			target: t_5,
			visited: false,
		},
	];

	const [text, setText] = useState(t_1);
	const [visited, setVisited] = useState([true, false, false, false, false]);
	const handleVisit = (id) => {
		let aux = visited;
		for (let i = 0; i < aux.length; i++) {
			if (i === id) {
				aux[i] = true;
			} else {
				aux[i] = false;
			}
		}
		setVisited(aux);
	};

	return (
		<DefaultPage
			title="Definições e diagnóstico de Hipertensão Arterial Sistêmica"
			refNumber={refNumber}
			openDrawer={openDrawer}
			prev="/_6"
			next="/_8"
			replay="/"
			titleCenter
		>
			<Content>
				<Box className="text">
					<Typography variant="body1" paragraph="true">
						Diante dessas informações de história clínica e exame físico, qual
						seria a sua conduta em relação ao quadro da Marilene? Vale resgatar
						os conceitos envolvidos nas elevações inadequadas da pressão
						arterial para essa resposta. <strong>Clique</strong> nos botões
						abaixo para relembrar cada um
					</Typography>
				</Box>
				<DivGrid marginTop={"2rem"}>
					{divs.map((element) => {
						return (
							<Div
								visited={visited[element.id]}
								onClick={() => {
									setText(element.target);
									handleVisit(element.id);
								}}
							>
								<Typography variant="body1" align="center">
									{element.label}
								</Typography>
							</Div>
						);
					})}
				</DivGrid>
				<Box
					display="flex"
					width="100%"
					borderRadius="15px"
					padding="1rem"
					marginBottom="16px"
					className="colored-box"
				>
					<Typography variant="body1">{text}</Typography>
				</Box>
			</Content>
		</DefaultPage>
	);
}
