import React, { useState, useEffect } from "react";
import DefaultPage from "../../theme/DefaultPage";
import { Typography, Box } from "@material-ui/core";
import { Content, Answer, Alternative } from "./styles";
import { Dialog, DialogContent, DialogContentText } from "@material-ui/core";
import API from "../../core/Lti/api";
import { questions } from "./data";
import { QuestionsContext } from "../../components/QuestionsSystem/contexts/QuestionsContext";
import {
  DialogButton,
  DialogStyles,
  ButtonText,
  CloseButton,
} from "./../../components/Dialog/styles";
import button_close from "../../assets/buttons/btn_fechar.svg";
import button_close_contraste from "../../assets/buttons/btn_fechar-contraste.png";
import themeLight from "../../theme/Palette/Light/palette.js";
import themeDark from "../../theme/Palette/Dark/palette.js";
import themeDefault from "../../theme";
import Slide from "@material-ui/core/Slide";
import { makeStyles } from "@material-ui/core/styles";
import { useSelector } from "react-redux";

const Transition = React.forwardRef(function Transition(props, ref) {
  return <Slide direction="up" ref={ref} {...props} />;
});

const useStyles = makeStyles({
  Dialog: {},
  DialogTitle: {
    // background: (contraste) => theme.palette.black.white,
    background: (theme) => theme.palette.black.white,
    color: (theme) => theme.palette.white.components,
    display: "flex",
    padding: themeDefault.spacing(2),
    "@media(min-width: 900px)": {
      padding: themeDefault.spacing(3),
    },
  },
  DialogTitleContent: {
    flexGrow: "1",
    display: "flex",
    alignItems: "center",
    color: (theme) => theme.palette.white.primary,
    h6: {
      lineHeight: 1.1,
    },
  },
  DialogContent: {
    background: (theme) => theme.palette.black.white,
    padding: themeDefault.spacing(2),
    maxHeight: "60vh",
    overflow: "auto",
    "@media(min-width: 900px)": {
      padding: themeDefault.spacing(3),
    },
  },
  DialogContentText: {
    color: (theme) => theme.palette.white.grey,
  },
  Divider: {
    background: (theme) => theme.palette.white.components,
    height: "2px",
  },
});

export default function () {
  const [done, setDone] = useState(false);
  const KEY = "ATV_PROCESSOS_HIPER_Q2";

  const [myAnswer, setMyAnswer] = useState(null);
  const [currentFeedback, setFeedback] = useState(questions[0].feedback);
  const [colors, setColors] = useState(["none", "none", "none", "none"]);
  const correctAnswer = 2;
  const [userTries, setTries] = useState(2);
  const questionsContext = React.useContext(QuestionsContext);

  const contraste = useSelector((state) => state.contraste);
  const theme = contraste ? themeDark : themeLight;
  const [open, setOpen] = React.useState(false);
  const classes = useStyles(theme);

  useEffect(() => {
    const handleColors = () => {
      const correct = "#33ab5f";
      const wrong = "#d8210b";
      const selected = "#1B647A";
      const nColor = "#00b5b1";
      if (done) {
        if (correctAnswer === 0) {
          setColors([correct, wrong, wrong, wrong]);
        } else if (correctAnswer === 1) {
          setColors([wrong, correct, wrong, wrong]);
        } else if (correctAnswer === 2) {
          setColors([wrong, wrong, correct, wrong]);
        } else if (correctAnswer === 3) {
          setColors([wrong, wrong, wrong, correct]);
        }
      } else {
        setColors([nColor, nColor, nColor, nColor]);
        if (myAnswer === 0) {
          setColors([selected, nColor, nColor, nColor]);
        } else if (myAnswer === 1) {
          setColors([nColor, selected, nColor, nColor]);
        } else if (myAnswer === 2) {
          setColors([nColor, nColor, selected, nColor]);
        } else if (myAnswer === 3) {
          setColors([nColor, nColor, nColor, selected]);
        }
      }
    };
    const init = async () => {
      const data = await API.getData(KEY);
      if (data != null) {
        setDone(true);
        setMyAnswer(data.answer);
        handleColors();
        setFeedback(data.feedback);
        setTries(data.tries);
      }
    };
    init();
  }, []);

  const sendAnswer = async (value) => {
    if (value === correctAnswer) {
      setTries(0);
      setDone(true);
    } else {
      setTries(userTries - 1 > 0 ? userTries - 1 : 0);
      setDone(userTries <= 1);
    }
    if (!done) {
      await API.setData(KEY, {
        answer: value,
        cAnswer: correctAnswer, // [0 - a, 1 - b, 2 - c, 3 - d]
        feedback: currentFeedback,
        tries: userTries,
      });
    }
  };

  useEffect(() => {
    const handleColors = () => {
      const correct = "#33ab5f";
      const wrong = "#d8210b";
      const selected = "#430D88";
      const nColor = "#222263";
      if (done) {
        if (correctAnswer === 0) {
          setColors([correct, wrong, wrong, wrong]);
        } else if (correctAnswer === 1) {
          setColors([wrong, correct, wrong, wrong]);
        } else if (correctAnswer === 2) {
          setColors([wrong, wrong, correct, wrong]);
        } else if (correctAnswer === 3) {
          setColors([wrong, wrong, wrong, correct]);
        }
      } else {
        setColors([nColor, nColor, nColor, nColor]);
        if (myAnswer === 0) {
          setColors([selected, nColor, nColor, nColor]);
        } else if (myAnswer === 1) {
          setColors([nColor, selected, nColor, nColor]);
        } else if (myAnswer === 2) {
          setColors([nColor, nColor, selected, nColor]);
        } else if (myAnswer === 3) {
          setColors([nColor, nColor, nColor, selected]);
        }
      }
    };
    handleColors();
  }, [myAnswer, done]);

  const neededAnswer = "Você precisa selecionar uma resposta";

  const handleClickOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };

  return (
    <DefaultPage prev="/_Q1" next="/final" title="Questão 2" titleCenter>
      <Content>
        <Box className="text">
          <Typography variant="body1">
            <p>
              Identifique os sinais e sintomas do paciente hipertenso com queixa
              aguda a seguir e o oriente adequadamente de acordo com a
              classificação de risco e vulnerabilidades:
            </p>
          </Typography>
          <Typography variant="h5" align="center" paragraph="true">
            Tentativas restantes: {userTries}
          </Typography>
        </Box>
        {questions.map((qt) => {
          return (
            <>
              <Alternative
                currentBG={colors[qt.id]}
                onClick={() => {
                  if (!done) {
                    setFeedback(qt.feedback);
                    setMyAnswer(qt.id);
                  }
                }}
              >
                <Typography variant="body1" align="left">
                  {qt.name + qt.label}
                </Typography>
              </Alternative>
            </>
          );
        })}

        <Box display="flex" justifyContent="center" alignItems="center">
          <Box className="dialog" marginTop="auto">
            <DialogStyles>
              {myAnswer != null ? (
                <>
                  <ButtonText
                    variant="body1"
                    className="indented"
                    onClick={() => {
                      handleClickOpen();
                      if (userTries >= 1) {
                        sendAnswer(myAnswer);
                      }
                    }}
                  >
                    <Typography variant="body1">
                      {done ? "Conferir Feedback" : "Enviar Resposta"}
                    </Typography>
                  </ButtonText>
                </>
              ) : (
                <></>
              )}

              <Dialog
                open={open}
                TransitionComponent={Transition}
                keepMounted
                onClose={handleClose}
                aria-labelledby="alert-dialog-slide-title"
                aria-describedby="alert-dialog-slide-description"
                maxWidth="md"
                className={classes.Dialog}
              >
                <Box
                  id="alert-dialog-slide-title"
                  className={classes.DialogTitle}
                >
                  <Box className={classes.DialogTitleContent}>
                    <Typography variant="h6">{"Feedback"}</Typography>
                  </Box>
                  <CloseButton onClick={handleClose}>
                    {contraste ? (
                      <img src={button_close_contraste} alt="Fechar" />
                    ) : (
                      <img src={button_close} alt="Fechar" />
                    )}
                  </CloseButton>
                </Box>
                <Box className={classes.Divider} />
                <DialogContent className={classes.DialogContent}>
                  <DialogContentText
                    id="alert-dialog-slide-description"
                    className={classes.DialogContentText}
                  >
                    <p>{currentFeedback}</p>
                  </DialogContentText>
                </DialogContent>
              </Dialog>
            </DialogStyles>
          </Box>
        </Box>
      </Content>
    </DefaultPage>
  );
}
