import React, { useEffect, useRef } from "react";
import { StyledContainerCapa, Iniciar } from "./stylesCapa";
import { ContentPage, StyledContainerPage } from "./stylesPage";
import { useSelector } from "react-redux";
import { Typography, Box } from "@material-ui/core";
import Header from "../../components/Header";
import Footer from "../../components/Footer";
import { IniciarCapa } from "../../components/RoundButton/icons";
import disqueIMG from "../../assets/images/Disque_saude.png";
function DefaultPage(props) {
  const contrasteValue = useSelector((state) => state.contraste);

  // para ativar a acessibilidade deixe o acess true
  // nao esqueca de ativar o vlibras alterando o disabled para enabled em public index ;
  const acess = false;

  const {
    capa,
    wallpaper,
    prev,
    next,
    replay,
    colorHeader,
    colorFooter,
    children,
    title,
    subtitle,
    refNumber,
    openDrawer,
    conteudoInterno,
    titleCenter,
    disque,
  } = props;

  function iniciar(event) {
    if (event.key === "Enter" && capa) {
      window.location.href = `#/_1`;
    }
    window.removeEventListener("keydown", iniciar);
  }
  window.addEventListener("keydown", iniciar);

  const headerref = useRef(Header);

  const openRef = (key) => {
    if (!headerref.current) {
      return;
    }
    headerref.current.openRef(key);
  };

  useEffect(() => {
    if (refNumber === 0 || refNumber === undefined) return;
    openRef(refNumber);
  }, [openDrawer, refNumber]);

  return capa ? (
    <StyledContainerCapa contraste={contrasteValue} wallpaper={wallpaper}>
      <Header color={colorHeader} acess={acess} nohome ref={headerref} />
      <Box id="container">
        <Box className="disque">
          {disque && <img src={disqueIMG} alt="Disque saúde 136" />}
        </Box>
        <Box className="content">
          <Box id="texts">
            <Box className="wrapper">
              <Box id="title">
                <Typography variant="h2">{title}</Typography>
                <br />
                <Typography variant="h3">{subtitle}</Typography>
              </Box>
              <Box>
                <Iniciar
                  role="button"
                  onClick={() => (window.location.href = "#/" + "_1")}
                  contraste={contrasteValue}
                >
                  <Typography
                    component="h4"
                    variant="body1"
                    style={{ opacity: "0", position: "absolute" }}
                  >
                    Botão Iniciar infográfico
                  </Typography>

                  <IniciarCapa />
                </Iniciar>
              </Box>
            </Box>
          </Box>
        </Box>
      </Box>
      <Footer color="transparent" logos />
    </StyledContainerCapa>
  ) : (
    <StyledContainerPage
      conteudoInterno={conteudoInterno}
      contraste={contrasteValue}
    >
      <Header color={colorHeader} acess={acess} ref={headerref} />
      <Box className="container">
        <ContentPage contraste={contrasteValue}>
          <Box className="contentPage">
            <Box className={`title ${titleCenter && "titleCenter"}`}>
              <Typography component="h2" variant="h5">
                {title}
              </Typography>
            </Box>
            {children}
          </Box>
        </ContentPage>
        {conteudoInterno && (
          <Footer prev={prev} next={next} replay={replay} color={colorFooter} />
        )}
      </Box>
      {!conteudoInterno && (
        <Footer prev={prev} next={next} replay={replay} color={colorFooter} />
      )}
    </StyledContainerPage>
  );
}

export default DefaultPage;
