import { createMuiTheme } from '@material-ui/core';

const defaultTheme = createMuiTheme();
const { breakpoints } = defaultTheme;

// calc([minimum size] + ([maximum size] - [minimum size]) * ((100vw - [minimum viewport width]) / ([maximum viewport width] - [minimum viewport width])));

const remToPx = (value) => value * 16;

function calculateFont(max, min, breakpoint) {
  switch (breakpoint) {
    case 'xs':
      return `calc(${min}px + (${max} - ${min}) * ((100vw - 320px) / (600 - 320)) * 2.5)`;
    case 'sm':
      return `calc(${min}px + (${max} - ${min}) * ((100vw - 600px) / (965 - 600)) * 2.5)`;
    case 'md':
      return `calc(${min}px + (${max} - ${min}) * ((100vw - 965px) / (1280 - 965)) * 2.5)`;
    case 'lg':
      return `calc(${min}px + (${max} - ${min}) * ((100vw - 1280px) / (1920 - 1280)) * 2.5)`;
    case 'xl':
      return `calc(${min}px + (${max} - ${min}) * ((100vw - 1920px) / (2560 - 1920)) * 2.5)`;
    default:
      return 'calc(1vw + 1vh)';
  }
}
export default {
  MuiTypography: {
    body1: {
      // fontSize: '40px !important'
      fontSize:
        'calc(16px + (22 - 16) * ((100vw - 600px) / (965 - 600)) * 2.5)',
      [breakpoints.up('sm')]: {
        fontSize:
          'calc(16px + (22 - 16) * ((100vw - 965px) / (1280 - 965)) * 2.5)',
      },
      [breakpoints.up('md')]: {
        fontSize:
          'calc(18px + (24 - 18) * ((100vw - 1280px) / (1920 - 1280)) * 2.5)',
      },
      [breakpoints.up('lg')]: {
        fontSize:
          'calc(18px + (24 - 18) * ((100vw - 1280px) / (1920 - 1280)) * 2.5)',
      },
      [breakpoints.up('xl')]: {
        fontSize:
          'calc(18px + (24 - 18) * ((100vw - 1280px) / (1920 - 1280)) * 2.5)',
      },
      lineHeight: '1.1',
      '@media (max-height: 700px)': {
        fontSize: 'calc(1.5vh + 1.5vh)',
      },
    },
    h1: {
      fontSize: calculateFont(remToPx(2.8), remToPx(2), 'xs'),
      [breakpoints.up(365)]: {
        fontSize: calculateFont(remToPx(3.5), remToPx(3), 'xs'),
      },
      [breakpoints.up('sm')]: {
        fontSize: calculateFont(remToPx(4.7129), remToPx(3.5), 'sm'),
      },
      [breakpoints.up('md')]: {
        fontSize: calculateFont(remToPx(5.3556), remToPx(4.7129), 'md'),
      },
      [breakpoints.up('lg')]: {
        fontSize: calculateFont(remToPx(5.4983), remToPx(5.0556), 'lg'),
      },
      [breakpoints.up('xl')]: {
        fontSize: calculateFont(remToPx(5.9983), remToPx(5.3556), 'xl'),
      },
    },
    h2: {
      fontSize: calculateFont(remToPx(2.375), remToPx(2), 'xs'),
      [breakpoints.up('sm')]: {
        fontSize: calculateFont(remToPx(2.9167), remToPx(2.375), 'sm'),
      },
      [breakpoints.up('md')]: {
        fontSize: calculateFont(remToPx(3.3333), remToPx(2.9167), 'md'),
      },
      [breakpoints.up('lg')]: {
        fontSize: calculateFont(remToPx(3.75), remToPx(3.3333), 'lg'),
      },
      [breakpoints.up('xl')]: {
        fontSize: calculateFont(remToPx(3.75), remToPx(3.3333), 'xl'),
      },
    },
    h3: {
      fontSize: calculateFont(remToPx(2), remToPx(1.75), 'xs'),
      [breakpoints.up('sm')]: {
        fontSize: calculateFont(remToPx(2.9167), remToPx(2), 'sm'),
      },
      [breakpoints.up('md')]: {
        fontSize: calculateFont(remToPx(2.7849), remToPx(2.9167), 'md'),
      },
      [breakpoints.up('lg')]: {
        fontSize: calculateFont(remToPx(2.9991), remToPx(2.7849), 'lg'),
      },
      [breakpoints.up('xl')]: {
        fontSize: calculateFont(remToPx(2.9991), remToPx(2.7849), 'xl'),
      },
    },
    h4: {
      fontSize: calculateFont(remToPx(1.5625), remToPx(1.25), 'xs'),
      [breakpoints.up('sm')]: {
        fontSize: calculateFont(remToPx(1.8219), remToPx(1.5625), 'sm'),
      },
      [breakpoints.up('md')]: {
        fontSize: calculateFont(remToPx(2.0243), remToPx(1.8219), 'md'),
      },
      [breakpoints.up('lg')]: {
        fontSize: calculateFont(remToPx(2.0243), remToPx(2.0243), 'lg'),
      },
      [breakpoints.up('xl')]: {
        fontSize: calculateFont(remToPx(2.0243), remToPx(2.0243), 'xl'),
      },
    },
    h5: {
      fontSize: calculateFont(remToPx(1.25), remToPx(1.1), 'xs'),
      [breakpoints.up('sm')]: {
        fontSize: calculateFont(remToPx(1.3118), remToPx(1.25), 'sm'),
      },
      [breakpoints.up('md')]: {
        fontSize: calculateFont(remToPx(1.4993), remToPx(1.3118), 'md'),
      },
    },
    h6: {
      fontSize: calculateFont(remToPx(1.125), remToPx(1.125), 'xs'),
      [breakpoints.up('sm')]: {
        fontSize: calculateFont(remToPx(1.25), remToPx(1.125), 'sm'),
      },
    },
    overline: {
      fontSize: calculateFont(remToPx(1.125), remToPx(1.125), 'xs'),
      [breakpoints.up('sm')]: {
        fontSize: calculateFont(remToPx(1.25), remToPx(1.125), 'sm'),
      },
    },
  },
};
